﻿using C1.Win.C1Editor;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace RibbonCommand
{
    public partial class Form1 : C1.Win.C1Ribbon.C1RibbonForm
    {
        C1.Win.C1Command.C1CommandHolder ch;
        C1.Win.C1Command.C1Command cutCommand;
        C1.Win.C1Command.C1Command copyCommand;
        C1.Win.C1Command.C1Command pasteCommand;
        C1.Win.C1Command.C1Command pasteTextCommand;
        C1.Win.C1Command.C1Command pasteSpecialCommand;
        C1.Win.C1Command.C1Command fontFamilyCommand;
        C1.Win.C1Command.C1Command fontSizeCommand;
        C1.Win.C1Command.C1Command boldCommand;
        C1.Win.C1Command.C1Command italicCommand;
        C1.Win.C1Command.C1Command underlineCommand;
        C1.Win.C1Command.C1Command insertTableCommand;
        C1.Win.C1Command.C1Command insertImageCommand;
        public Form1()
        {
            
            InitializeComponent();
            ch = C1.Win.C1Command.C1CommandHolder.CreateCommandHolder(this);
            cutCommand = ch.CreateCommand();
            copyCommand = ch.CreateCommand();
            pasteCommand = ch.CreateCommand();
            pasteTextCommand = ch.CreateCommand();
            pasteSpecialCommand = ch.CreateCommand();
            fontFamilyCommand = ch.CreateCommand();
            fontSizeCommand = ch.CreateCommand();
            boldCommand = ch.CreateCommand();
            italicCommand = ch.CreateCommand();
            underlineCommand = ch.CreateCommand();
            insertTableCommand = ch.CreateCommand();
            insertImageCommand = ch.CreateCommand();

            cutCommand.Click += (s, a) =>
            {
                _editor.Cut();
            };
            copyCommand.Click += (s, a) =>
            {
                _editor.Copy();
            };
            pasteCommand.Click += (s, a) =>
            {
                _editor.Paste();
            };
            pasteTextCommand.Click += (s, a) =>
            {
                _editor.PasteAsText();
            };
            pasteSpecialCommand.Click += (s, a) =>
            {
                _editor.Paste();
            };
            fontFamilyCommand.Click += (s, a) =>
            {
                string value = cmbFontFace.Text;
                if (String.IsNullOrEmpty(value))
                    _editor.Selection.RemoveStyle("font-family", null);
                else
                    _editor.Selection.ApplyStyle("font-family", value, C1StyleType.Character);
            };
            fontSizeCommand.Click += (s, a) =>
            {
                string value = cmbFontSize.Text;
                if (String.IsNullOrEmpty(value))
                    _editor.Selection.RemoveStyle("font-size", null);
                else
                    _editor.Selection.ApplyStyle("font-size", value + (value.EndsWith("pt") ? "" : "pt"), C1StyleType.Character);
            };
            boldCommand.Click += (s, a) =>
            {
                bool value = btnBold.Pressed;
                if (value)
                {
                    _editor.Selection.ApplyTag("strong");
                }
                else
                {
                    _editor.BeginTransaction("Remove style");
                    try
                    {
                        _editor.Selection.RemoveTag("strong");
                        _editor.Selection.RemoveTag("b");
                        _editor.CommitTransaction();
                    }
                    catch
                    {
                        _editor.RollbackTransaction();
                    }
                }
            };
            italicCommand.Click += (s, a) =>
            {
                bool value = btnItalic.Pressed;
                if (value)
                {
                    _editor.Selection.ApplyTag("em");
                }
                else
                {
                    _editor.BeginTransaction("Remove style");
                    try
                    {
                        _editor.Selection.RemoveTag("em");
                        _editor.Selection.RemoveTag("i");
                        _editor.CommitTransaction();
                    }
                    catch
                    {
                        _editor.RollbackTransaction();
                    }
                }
            };
            underlineCommand.Click += (s, a) =>
            {
                bool value = btnUnderline.Pressed;
                if (value)
                {
                    _editor.Selection.ApplyStyle("text-decoration", "underline", C1StyleType.Character);
                }
                else
                {
                    _editor.BeginTransaction("Remove style");
                    try
                    {
                        _editor.Selection.RemoveStyle("text-decoration", null);
                        _editor.Selection.RemoveTag("u");
                        _editor.CommitTransaction();
                    }
                    catch
                    {
                        _editor.RollbackTransaction();
                    }
                }
            };
            insertTableCommand.Click += (s, a) =>
            {
                _editor.ShowDialog(DialogType.NewTable);
            };
            insertImageCommand.Click += (s, a) =>
            {
                _editor.ShowDialog(DialogType.Image);
            };

            ch.SetC1Command(btnCut, cutCommand);
            ch.SetC1Command(btnCopy, copyCommand);
            ch.SetC1Command(PasteText, pasteCommand);
            ch.SetC1Command(PasteText, pasteTextCommand);
            ch.SetC1Command(PasteSpecial, pasteSpecialCommand);
            ch.SetC1Command(cmbFontFace, fontFamilyCommand);
            ch.SetC1Command(cmbFontSize, fontSizeCommand);
            ch.SetC1Command(btnBold, boldCommand);
            ch.SetC1Command(btnItalic, italicCommand);
            ch.SetC1Command(btnUnderline, underlineCommand);
            ch.SetC1Command(btnInsertTable, insertTableCommand);
            ch.SetC1Command(btnPicture, insertImageCommand);
        }

        private void Editor_SelectionChanged(object sender, EventArgs e)
        {
            if (ch != null)
            {
                if (_editor.SelectionLength > 0)
                {
                    cutCommand.Enabled = _editor.CanCut;
                    copyCommand.Enabled = _editor.CanCopy;
                    pasteCommand.Enabled = _editor.CanPaste;
                    pasteTextCommand.Enabled = _editor.CanPasteAsText;
                    pasteSpecialCommand.Enabled = _editor.CanPaste;
                }
                else
                {
                    cutCommand.Enabled = copyCommand.Enabled = false;
                    pasteCommand.Enabled = _editor.CanPaste;
                    pasteTextCommand.Enabled = _editor.CanPasteAsText;
                    pasteSpecialCommand.Enabled = _editor.CanPaste;
                }

                cmbFontFace.Text = (_editor.Mode == EditorMode.Design ? _editor.Selection.GetStyleValue("font-family") : string.Empty);
                if (_editor.Mode == EditorMode.Design)
                {
                    string size = _editor.Selection.GetStyleValue("font-size") ?? string.Empty;
                    cmbFontSize.Text =  size.EndsWith("pt") ? size.Substring(0, size.Length - 2) : size;
                }
                else
                    cmbFontSize.Text =  string.Empty;

                btnBold.Pressed = (_editor.Mode == EditorMode.Design ?
                   (_editor.Selection.IsTagApplied("strong") || _editor.Selection.IsTagApplied("b")) :
                   false);

                btnItalic.Pressed = (_editor.Mode == EditorMode.Design ?
                    (_editor.Selection.IsTagApplied("em") || _editor.Selection.IsTagApplied("i")) :
                    false);
                if (_editor.Mode == EditorMode.Design)
                {
                    bool res = _editor.Selection.IsTagApplied("u");
                    if (!res && _editor.Selection.IsStyleApplied("text-decoration"))
                        res = string.Compare(_editor.Selection.GetStyleValue("text-decoration", C1StyleType.Character), "underline", true) == 0;
                    btnUnderline.Pressed = res;
                }
                else
                    btnUnderline.Pressed = false;
            }
        }
    }
}
